from mpl_toolkits.mplot3d import Axes3D
import matplotlib.pyplot as plt
import numpy as np
import math

class BiVarNorm:
    """
            Bivariate normal distribution
    """
    def __init__(self, rho):
        self.rho = rho

    def value(self, x, y):
        v = (x**2 + y**2 - 2 * self.rho * x * y) / (2.0 * (1.0 - self.rho**2))
        v = np.exp(-v) / ((2.0 * math.pi * (1.0 - self.rho**2)) ** 0.5)
        return v
    
while True:
    rho = float(input('rho = '))
    if math.fabs(rho) >= 1.0:
        break
    fig = plt.figure()
    ax = Axes3D(fig)
    Xg = np.arange(-4.0, 4.0, 0.1)
    Yg = np.arange(-4.0, 4.0, 0.1)
    X, Y = np.meshgrid(Xg, Yg)
    bi_norm = BiVarNorm(rho)

    ax.plot_surface(X, Y, bi_norm.value(X, Y), rstride = 1, cstride = 1, cmap = plt.cm.coolwarm)

    plt.show()

print('\nGoodbye !\n')
